@@ -6,8 +6,8 @@
 // #     Description: Provides dynamic client-side access to (D)COM applications from within R.
 // # License: GPL-2
 // # Collate: classes.R COMLists.S COMError.R com.R debug.S zzz.R runTime.S
-// # URL: http://www.omegahat.org/RDCOMClient, http://www.omegahat.org
-// # http://www.omegahat.org/bugs
+// # URL: http://www.omegahat.net/RDCOMClient, http://www.omegahat.net
+// # http://www.omegahat.net/bugs
 
 #include "RCOMObject.h"
 #include <oleauto.h>
@@ -53,12 +53,11 @@ char *
 FromBstr(BSTR str)
 {
   char *ptr = NULL;
-  DWORD len;
 
   if(!str)
     return(NULL);
 
-  len = wcslen(str);
+  int len = WideCharToMultiByte(CP_ACP, 0, str, -1, NULL, 0, NULL, NULL);
 
   if(len < 1)
     len = 0;
@@ -66,9 +65,7 @@ FromBstr(BSTR str)
   ptr = (char *) S_alloc(len+1, sizeof(char));
   ptr[len] = '\0';
   if(len > 0) {
-    DWORD ok = WideCharToMultiByte(CP_ACP, 0, str, len, ptr, len, NULL, NULL);
-    if(ok == 0) 
-      ptr = NULL;
+    WideCharToMultiByte(CP_ACP, 0, str, -1, ptr, len, NULL, NULL);
   }
 
   return(ptr);
@@ -382,17 +379,13 @@ R_convertDCOMObjectToR(VARIANT *var)
 
 
   if(V_ISARRAY(var)) {
-#if defined(RDCOM_VERBOSE) && RDCOM_VERBOSE
-  errorLog("Finishing convertDCOMObjectToR - convert array\n");
-#endif
+
     return(convertArrayToR(var));
   } else if(V_VT(var) == VT_DISPATCH || (V_ISBYREF(var) && ((V_VT(var) & (~ VT_BYREF)) == VT_DISPATCH)) ) {
     IDispatch *ptr;
     if(V_ISBYREF(var)) {
 
-#if defined(RDCOM_VERBOSE) && RDCOM_VERBOSE
-      errorLog("BYREF and DISPATCH in convertDCOMObjectToR\n");
-#endif
+
 
       IDispatch **tmp = V_DISPATCHREF(var);
       if(!tmp)
@@ -404,9 +397,7 @@ R_convertDCOMObjectToR(VARIANT *var)
     if(ptr) 
       ptr->AddRef();
     ans = R_createRCOMUnknownObject((void*) ptr, "COMIDispatch");
-#if defined(RDCOM_VERBOSE) && RDCOM_VERBOSE
-    errorLog("Finished convertDCOMObjectToR  COMIDispatch\n");
-#endif
+
     return(ans);
   }
 
@@ -422,9 +413,7 @@ R_convertDCOMObjectToR(VARIANT *var)
     if(rtype == VT_BSTR) {
         BSTR *tmp;
         const char *ptr = "";
-#if defined(RDCOM_VERBOSE) && RDCOM_VERBOSE
-	errorLog("BYREF and BSTR convertDCOMObjectToR  (scalar string)\n");
-#endif
+
         tmp = V_BSTRREF(var);
         if(tmp)
   	  ptr = FromBstr(*tmp);
@@ -524,9 +513,7 @@ R_convertDCOMObjectToR(VARIANT *var)
     ans = createRVariantObject(var, V_VT(var));
   }
 
-#if defined(RDCOM_VERBOSE) && RDCOM_VERBOSE
-  errorLog("Finished convertDCOMObjectToR\n");
-#endif
+
 
   return(ans);
 }
